from odoo import fields, models, _


class SupplyPoint(models.Model):
    _name = "energy_selfconsumption.supply_point"
    _description = "Energy Supply Point"
    _inherit = ["mail.thread", "mail.activity.mixin"]

    _sql_constraints = {
        (
            "unique_code_company_id",
            "unique (code, company_id)",
            _("A supply point with this code already exists."),
        )
    }

    name = fields.Char(required=True)
    code = fields.Char(string="CUPS", required=True)
    owner_id = fields.Many2one("res.partner", string="Owner", required=True,
                               help="Partner with the legal obligation of the supply point")
    partner_id = fields.Many2one("res.partner", string="Partner", required=True,
                                 help="Partner subscribed to the self-consumption project")
    company_id = fields.Many2one(
        "res.company", default=lambda self: self.env.company, readonly=True
    )

    # Address fields
    street = fields.Char(required=True)
    street2 = fields.Char(required=True)
    zip = fields.Char(change_default=True, required=True)
    city = fields.Char(required=True)
    state_id = fields.Many2one(
        "res.country.state",
        string="State",
        ondelete="restrict",
        domain="[('country_id', '=?', country_id)]",
        required=True,
    )
    country_id = fields.Many2one(
        "res.country", string="Country", ondelete="restrict", required=True
    )

    supply_point_assignation_ids = fields.One2many('energy_selfconsumption.supply_point_assignation','supply_point_id',
                                                   readonly=True)
